chars_view class

Constructors

chars_view(String _str, [int _pos = 0])

Properties

current String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(int offset) chars_view
operator -(chars_view other) int
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) String