complex class

Constructors

complex(double real, double imag)

Properties

hashCode int
The hash code for this object.
no setteroverride
I complex
no setter
i complex
no setter
imag double
getter/setter pair
real double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator *(Object other) complex
operator +(Object other) complex
operator -(Object other) complex
operator /(Object other) complex
operator ==(Object other) bool
The equality operator.
override