pointer_view<T> class

Constructors

pointer_view(List<T> _list, [int _pos = 0])

Properties

current ↔ T
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(int offset) → void
clone() pointer_view<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(int offset) pointer_view<T>
operator -(pointer_view<T> other) int
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → T

Static Methods

copy<T>(pointer_view<T> dest, pointer_view<T> src) → void